@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -40,7 +40,7 @@ class VendorInvoiceHandler(BatchHandler):
     """
     Handler for vendor invoice batches.
     """
-    batch_model_class = model.VendorInvoice
+    batch_model_class = model.VendorInvoiceBatch
     po_number_title = "PO Number"
 
     def make_batch(self, session, progress=None, **kwargs):
