@@ -67,9 +67,9 @@ def record_changes(session, recorder=None, config=None):
         if config:
             spec = config.get('rattail.db', 'changes.recorder', usedb=False)
             if spec:
-                recorder = load_object(spec)()
+                recorder = load_object(spec)(config)
         if not recorder:
-            recorder = ChangeRecorder()
+            recorder = ChangeRecorder(config)
     else:
         raise ValueError("Invalid 'recorder' parameter: {}".format(repr(recorder)))
 
@@ -108,6 +108,10 @@ class ChangeRecorder(object):
     if parse_version(sa.__version__) < parse_version('0.8'):
         is_modified_kw['passive'] = True
 
+    def __init__(self, config):
+        self.config = config
+        self.model = config.get_model()
+
     def __call__(self, session, flush_context, instances):
         """
         Method invoked when session ``before_flush`` event occurs.
