@@ -148,18 +148,26 @@ class ContactMixin(object):
     _contact_phone_model = None
     _contact_address_model = None
 
-    def first_email(self, **kwargs):
+    def first_email(self, invalid=False, **kwargs):
         """
         Return the first available email record for the contact.
-        """
-        if self.emails:
-            return self.emails[0]
 
-    def first_email_address(self, **kwargs):
+        :param invalid: If true, then this may return an email marked
+           invalid; if false then only valid email will be returned.
+        """
+        if invalid:
+            emails = self.emails
+        else:
+            emails = [email for email in self.emails
+                      if not email.invalid]
+        if emails:
+            return emails[0]
+
+    def first_email_address(self, invalid=False, **kwargs):
         """
         Return the first available email address for the contact.
         """
-        email = self.first_email()
+        email = self.first_email(invalid=invalid)
         if email:
             return email.address
 
