@@ -35,7 +35,7 @@ from sqlalchemy.ext.orderinglist import ordering_list
 from sqlalchemy.ext.declarative import declared_attr
 
 from rattail.db.model import Base, uuid_column
-from rattail.db.model import Store, Customer, Person, Product, User
+from rattail.db.model import Store, Customer, Person, Product, User, Note
 from rattail.db.types import GPCType
 
 
@@ -346,3 +346,25 @@ class CustomerOrderItemEvent(Base):
     note = sa.Column(sa.Text(), nullable=True, doc="""
     Optional note recorded for the event.
     """)
+
+
+class CustomerOrderItemNote(Note):
+    """
+    Represents a note attached to an order item.
+    """
+    __mapper_args__ = {'polymorphic_identity': 'CustomerOrderItem'}
+
+CustomerOrderItem.notes = orm.relationship(
+    CustomerOrderItemNote,
+    primaryjoin=CustomerOrderItemNote.parent_uuid == CustomerOrderItem.uuid,
+    foreign_keys=[CustomerOrderItemNote.parent_uuid],
+    order_by=CustomerOrderItemNote.created,
+    cascade='all, delete-orphan',
+    doc="""
+    Sequence of notes attached to the order item.
+    """,
+    backref=orm.backref(
+        'person',
+        doc="""
+        Reference to the order item to which the note is attached.
+        """))
