@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,9 @@
 Data Models for Label Printing
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
+import six
 import sqlalchemy as sa
 from sqlalchemy.orm import object_session
 
@@ -33,6 +34,7 @@ from .core import Base, uuid_column
 from rattail.util import load_object
 
 
+@six.python_2_unicode_compatible
 class LabelProfile(Base):
     """
     Represents a collection of settings for product label printing.
@@ -42,18 +44,28 @@ class LabelProfile(Base):
 
     uuid = uuid_column()
     ordinal = sa.Column(sa.Integer())
-    code = sa.Column(sa.String(length=3))
+
+    code = sa.Column(sa.String(length=30), nullable=True, doc="""
+    Supposedly unique "code" for the label profile.  May be useful for
+    identification of a common label type across nodes, for instance.
+    """)
+
     description = sa.Column(sa.String(length=50))
     printer_spec = sa.Column(sa.String(length=255))
     formatter_spec = sa.Column(sa.String(length=255))
     format = sa.Column(sa.Text())
     visible = sa.Column(sa.Boolean())
 
+    sync_me = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating whether this label profile should be synced across "all"
+    other Rattail systems across the organization.
+    """)
+
     _printer = None
     _formatter = None
 
-    def __unicode__(self):
-        return unicode(self.description or '')
+    def __str__(self):
+        return str(self.description or '')
 
     # TODO: Copy elsewhere, deprecate and remove this logic (not strictly an
     # API call from within data model, but should go with the others, below).
