@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 
 from __future__ import unicode_literals, absolute_import
 
@@ -9,6 +9,7 @@ from mock import Mock, patch, call
 from rattail.db import model
 from rattail.db.util import QuerySequence
 from rattail.importing import importers
+from rattail.util import OrderedDict
 from rattail.tests import NullProgress, RattailTestCase
 from rattail.tests.importing import ImporterTester
 
@@ -189,7 +190,12 @@ class TestImporter(TestCase):
         keys = importer.get_deletion_keys()
         self.assertEqual(keys, set())
 
-        importer.cached_local_data = {'delete-me': object()}
+        importer.cached_local_data = {
+            'delete-me': {
+                'object': object(),
+                'data': {},
+            },
+        }
         keys = importer.get_deletion_keys()
         self.assertEqual(keys, set(['delete-me']))
 
@@ -222,6 +228,7 @@ class TestImporter(TestCase):
         # batch size determines how often flush occurs
         data = [{'id': i} for i in range(1, 101)]
         importer = importers.Importer(model_name='Foo', key='id', fields=['id'], empty_local_data=True)
+        importer.handler = Mock(local_title="Nevermind")
         with patch.object(importer, 'create_object'): # just mock that out
             with patch.object(importer, 'flush_create_update') as flush:
 
@@ -359,14 +366,15 @@ class MockImporter(importers.Importer):
 class TestMockImporter(ImporterTester, TestCase):
     importer_class = MockImporter
 
-    sample_data = {
-        '16oz': {'upc': '00074305001161', 'description': "Apple Cider Vinegar 16oz"},
-        '32oz': {'upc': '00074305001321', 'description': "Apple Cider Vinegar 32oz"},
-        '1gal': {'upc': '00074305011283', 'description': "Apple Cider Vinegar 1gal"},
-    }
+    sample_data = OrderedDict([
+        ('16oz', {'upc': '00074305001161', 'description': "Apple Cider Vinegar 16oz"}),
+        ('32oz', {'upc': '00074305001321', 'description': "Apple Cider Vinegar 32oz"}),
+        ('1gal', {'upc': '00074305011283', 'description': "Apple Cider Vinegar 1gal"}),
+    ])
 
     def setUp(self):
         self.importer = self.make_importer()
+        self.importer.handler = Mock(local_title="Nevermind")
 
     def test_create(self):
         local = self.copy_data()
